@@ -1,8 +1,8 @@
 # debian/control/field/section -- lintian check script -*- perl -*-
 #
-# Copyright © 2004 Marc Brockschmidt
-# Copyright © 2020 Chris Lamb <lamby@debian.org>
-# Copyright © 2020-2021 Felix Lechner
+# Copyright (C) 2004 Marc Brockschmidt
+# Copyright (C) 2020 Chris Lamb <lamby@debian.org>
+# Copyright (C) 2020-2021 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, you can find it on the World Wide
-# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
+# Web at https://www.gnu.org/copyleft/gpl.html, or write to the Free
 # Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301, USA.
 
@@ -37,7 +37,7 @@ sub source {
     my $control = $self->processable->debian_control;
     my $source_fields = $control->source_fields;
 
-    $self->hint('no-source-section')
+    $self->pointed_hint('no-source-section', $control->item->pointer)
       unless $source_fields->declares('Section');
 
     return;
